# Table of Contents

- [inventory-builder](<./inventory-builder.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Inventory Builder](<./Inventory-Builder.md>)
  - [Overview](<./Inventory-Builder/Overview.md>)
  - [Benefits](<./Inventory-Builder/Benefits.md>)
  - [Prerequisites](<./Inventory-Builder/Prerequisites.md>)
  - [Activating the Inventory Builder](<./Inventory-Builder/Activating-the-Inventory-Builder.md>)
  - [Extracting Fact Sheets and Relations from Files](<./Inventory-Builder/Extracting-Fact-Sheets-and-Relations-from-Files.md>)
  - [Creating Fact Sheets and Relations from the Inventory Builder Inbox](<./Inventory-Builder/Creating-Fact-Sheets-and-Relations-from-the-Inventory-Builder-Inbox.md>)
  - [Individually Reviewing and Creating Fact Sheets and Relations](<./Inventory-Builder/Individually-Reviewing-and-Creating-Fact-Sheets-and-Relations.md>)
  - [Creating Fact Sheets and Relations for Multiple Items](<./Inventory-Builder/Creating-Fact-Sheets-and-Relations-for-Multiple-Items.md>)
  - [Rejecting Discovered Items](<./Inventory-Builder/Rejecting-Discovered-Items.md>)
  - [Accessing Past Uploads and Analysis](<./Inventory-Builder/Accessing-Past-Uploads-and-Analysis.md>)
  - [Best Practice Prompts for Using Inventory Builder Effectively](<./Inventory-Builder/Best-Practice-Prompts-for-Using-Inventory-Builder-Effectively.md>)
  - [Was this page helpful?](<./Inventory-Builder/Was-this-page-helpful.md>)
